@@ -1,5 +1,6 @@
 from enum import Enum
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     Collection,
@@ -10,7 +11,6 @@ from typing import (
     NamedTuple,
     Optional,
     Tuple,
-    TYPE_CHECKING,
     Type,
     TypeVar,
     Union,
@@ -21,8 +21,8 @@ from typing import (
 from ..error import GraphQLError
 from ..language import (
     EnumTypeDefinitionNode,
-    EnumValueDefinitionNode,
     EnumTypeExtensionNode,
+    EnumValueDefinitionNode,
     EnumValueNode,
     FieldDefinitionNode,
     FieldNode,
@@ -47,16 +47,16 @@ from ..language import (
 from ..pyutils import (
     AwaitableOrValue,
     Path,
+    Undefined,
     cached_property,
     did_you_mean,
     inspect,
     is_collection,
     is_description,
     suggestion_list,
-    Undefined,
 )
 from ..utilities.value_from_ast_untyped import value_from_ast_untyped
-from .assert_name import assert_name, assert_enum_value_name
+from .assert_name import assert_enum_value_name, assert_name
 
 try:
     from typing import TypedDict
@@ -319,14 +319,22 @@ class GraphQLScalarType(GraphQLNamedType):
     and are defined with a name and a series of functions used to parse input from ast
     or variables and to ensure validity.
 
-    If a type's serialize function does not return a value (i.e. it returns ``None``),
-    then no error will be included in the response.
+    If a type's serialize function returns ``None``, then an error will be raised and a
+    ``None`` value will be returned in the response. It is always better to validate.
 
     Example::
 
-        def serialize_odd(value):
-            if value % 2 == 1:
-                return value
+        def serialize_odd(value: Any) -> int:
+            try:
+                value = int(value)
+            except ValueError:
+                raise GraphQLError(
+                    f"Scalar 'Odd' cannot represent '{value}'"
+                    " since it is not an integer.")
+            if not value % 2:
+                raise GraphQLError(
+                    f"Scalar 'Odd' cannot represent '{value}' since it is even.")
+            return value
 
         odd_type = GraphQLScalarType('Odd', serialize=serialize_odd)
 
@@ -430,16 +438,22 @@ class GraphQLScalarType(GraphQLNamedType):
         # noinspection PyArgumentList
         return GraphQLScalarTypeKwargs(  # type: ignore
             super().to_kwargs(),
-            serialize=None
-            if self.serialize is GraphQLScalarType.serialize
-            else self.serialize,
-            parse_value=None
-            if self.parse_value is GraphQLScalarType.parse_value
-            else self.parse_value,
-            parse_literal=None
-            if getattr(self.parse_literal, "__func__", None)
-            is GraphQLScalarType.parse_literal
-            else self.parse_literal,
+            serialize=(
+                None
+                if self.serialize is GraphQLScalarType.serialize
+                else self.serialize
+            ),
+            parse_value=(
+                None
+                if self.parse_value is GraphQLScalarType.parse_value
+                else self.parse_value
+            ),
+            parse_literal=(
+                None
+                if getattr(self.parse_literal, "__func__", None)
+                is GraphQLScalarType.parse_literal
+                else self.parse_literal
+            ),
             specified_by_url=self.specified_by_url,
         )
 
@@ -509,9 +523,11 @@ class GraphQLField:
             )
         else:
             args = {
-                assert_name(name): value
-                if isinstance(value, GraphQLArgument)
-                else GraphQLArgument(cast(GraphQLInputType, value))
+                assert_name(name): (
+                    value
+                    if isinstance(value, GraphQLArgument)
+                    else GraphQLArgument(cast(GraphQLInputType, value))
+                )
                 for name, value in args.items()
             }
         if resolve is not None and not callable(resolve):
@@ -816,9 +832,11 @@ class GraphQLObjectType(GraphQLNamedType):
                 f"{self.name} fields must be GraphQLField or output type objects."
             )
         return {
-            assert_name(name): value
-            if isinstance(value, GraphQLField)
-            else GraphQLField(value)  # type: ignore
+            assert_name(name): (
+                value
+                if isinstance(value, GraphQLField)
+                else GraphQLField(value)  # type: ignore
+            )
             for name, value in fields.items()
         }
 
@@ -950,9 +968,11 @@ class GraphQLInterfaceType(GraphQLNamedType):
                 f"{self.name} fields must be GraphQLField or output type objects."
             )
         return {
-            assert_name(name): value
-            if isinstance(value, GraphQLField)
-            else GraphQLField(value)  # type: ignore
+            assert_name(name): (
+                value
+                if isinstance(value, GraphQLField)
+                else GraphQLField(value)  # type: ignore
+            )
             for name, value in fields.items()
         }
 
@@ -1159,12 +1179,12 @@ class GraphQLEnumType(GraphQLNamedType):
             ):
                 try:
                     # noinspection PyTypeChecker
-                    values = dict(values)  # type: ignore
-                except (TypeError, ValueError):
+                    values = dict(values)
+                except (TypeError, ValueError) as error:
                     raise TypeError(
                         f"{name} values must be an Enum or a mapping"
                         " with value names as keys."
-                    )
+                    ) from error
             values = cast(Dict[str, Any], values)
         else:
             values = cast(Dict[str, Enum], values)
@@ -1173,9 +1193,11 @@ class GraphQLEnumType(GraphQLNamedType):
             elif names_as_values is True:
                 values = {key: key for key in values}
         values = {
-            assert_enum_value_name(key): value
-            if isinstance(value, GraphQLEnumValue)
-            else GraphQLEnumValue(value)
+            assert_enum_value_name(key): (
+                value
+                if isinstance(value, GraphQLEnumValue)
+                else GraphQLEnumValue(value)
+            )
             for key, value in values.items()
         }
         if ast_node and not isinstance(ast_node, EnumTypeDefinitionNode):
@@ -1433,9 +1455,11 @@ class GraphQLInputObjectType(GraphQLNamedType):
         return GraphQLInputObjectTypeKwargs(  # type: ignore
             super().to_kwargs(),
             fields=self.fields.copy(),
-            out_type=None
-            if self.out_type is GraphQLInputObjectType.out_type
-            else self.out_type,
+            out_type=(
+                None
+                if self.out_type is GraphQLInputObjectType.out_type
+                else self.out_type
+            ),
         )
 
     def __copy__(self) -> "GraphQLInputObjectType":  # pragma: no cover
@@ -1465,9 +1489,11 @@ class GraphQLInputObjectType(GraphQLNamedType):
                 " GraphQLInputField or input type objects."
             )
         return {
-            assert_name(name): value
-            if isinstance(value, GraphQLInputField)
-            else GraphQLInputField(value)  # type: ignore
+            assert_name(name): (
+                value
+                if isinstance(value, GraphQLInputField)
+                else GraphQLInputField(value)  # type: ignore
+            )
             for name, value in fields.items()
         }
 
@@ -1687,18 +1713,15 @@ def assert_nullable_type(type_: Any) -> GraphQLNullableType:
 
 
 @overload
-def get_nullable_type(type_: None) -> None:
-    ...
+def get_nullable_type(type_: None) -> None: ...
 
 
 @overload
-def get_nullable_type(type_: GraphQLNullableType) -> GraphQLNullableType:
-    ...
+def get_nullable_type(type_: GraphQLNullableType) -> GraphQLNullableType: ...
 
 
 @overload
-def get_nullable_type(type_: GraphQLNonNull) -> GraphQLNullableType:
-    ...
+def get_nullable_type(type_: GraphQLNonNull) -> GraphQLNullableType: ...
 
 
 def get_nullable_type(
@@ -1790,13 +1813,11 @@ def assert_named_type(type_: Any) -> GraphQLNamedType:
 
 
 @overload
-def get_named_type(type_: None) -> None:
-    ...
+def get_named_type(type_: None) -> None: ...
 
 
 @overload
-def get_named_type(type_: GraphQLType) -> GraphQLNamedType:
-    ...
+def get_named_type(type_: GraphQLType) -> GraphQLNamedType: ...
 
 
 def get_named_type(type_: Optional[GraphQLType]) -> Optional[GraphQLNamedType]:
