@@ -661,9 +661,11 @@ def extend_schema_impl(
             replace_directive(directive) for directive in schema_kwargs["directives"]
         )
         + tuple(build_directive(directive) for directive in directive_defs),
-        description=schema_def.description.value
-        if schema_def and schema_def.description
-        else None,
+        description=(
+            schema_def.description.value
+            if schema_def and schema_def.description
+            else None
+        ),
         extensions={},
         ast_node=schema_def or schema_kwargs["ast_node"],
         extension_ast_nodes=schema_kwargs["extension_ast_nodes"]
